@@ -1,7 +1,8 @@
+# nolint start
 #' 150 Color Palettes from Canva
 #'
 #' 150 four-color palettes by the
-#' \href{https://designschool.canva.com}{canva.com} design school.
+#' \href{https://www.canva.com/learn/}{canva.com} design school.
 #' These palettes were derived from photos and "impactful websites".
 #'
 #' @format A named \code{list} of character vector.
@@ -10,21 +11,17 @@
 #'
 #' @references
 #' \itemize{
-#' \item{Janie Kliever, \href{https://designschool.canva.com/blog/100-color-combinations/}{100 Brilliant Color Combinations and How to Apply Them to Your Designs},
+#' \item{Janie Kliever, \href{https://www.canva.com/learn/100-color-combinations/}{100 Brilliant Color Combinations and How to Apply Them to Your Designs},
 #'   \emph{Canva.com}, June 20, 2015.}
-#' \item{Mary Stribley, \href{https://designschool.canva.com/blog/website-color-schemes/}{Website Color Schemes: The Palettes of 50 Visually Impactful Websites to Inspire You},
+#' \item{Mary Stribley, \href{https://www.canva.com/learn/website-color-schemes/}{Website Color Schemes: The Palettes of 50 Visually Impactful Websites to Inspire You},
 #'   \emph{Canva.com}, January 26, 2016.}
-#' \item{Pablo Saenz de Tejeda,
-#'   \href{http://makeadifferencewithdata.com/2017/01/150-paletas-colores-tableau/}{150 paletas de colores para Tableau},
-#'   January 1, 2017.}
 #' \item{Schwabish, Jonathan.
 #'    \href{https://policyviz.com/2017/01/12/150-color-palettes-for-excel/}{150+ Color Palettes for Excel},
 #'     \emph{PolicyViz}, January 12, 2017.}
 #' }
-#' @source
-#' \url{http://makeadifferencewithdata.com/wp-content/uploads/2016/12/color-palettes.txt}
 #' @example inst/examples/ex-canva_pal.R
 "canva_palettes"
+# nolint end
 
 #' Canva.com color palettes
 #'
@@ -47,11 +44,11 @@ canva_pal <- function(palette = "Fresh and bright") {
 #' Color scale for canva.com color palettes described in
 #' \code{\link{canva_palettes}()}.
 #'
-#' @param ... Arguments passed to \code{\link{discrete_scale}()}.
+#' @param ... Arguments passed to \code{\link[ggplot2]{discrete_scale}()}.
 #' @inheritParams canva_pal
 #' @export
 scale_colour_canva <- function(..., palette = "Fresh and bright") {
-  discrete_scale("colour", "canva", canva_pal(palette), ...)
+  discrete_scale("colour", palette = canva_pal(palette), ...)
 }
 
 #' @export
@@ -61,5 +58,5 @@ scale_color_canva <- scale_colour_canva
 #' @export
 #' @rdname scale_colour_canva
 scale_fill_canva <- function(..., palette = "Fresh and bright") {
-  discrete_scale("fill", "canva", canva_pal(palette), ...)
+  discrete_scale("fill", palette = canva_pal(palette), ...)
 }
