@@ -9,12 +9,8 @@ test_that("colorblind_pal raises warning with to large n", {
   expect_warning(colorblind_pal()(20))
 })
 
-test_that("scale_colour_colorblind works", {
-  expect_s3_class(scale_colour_colorblind(), "ScaleDiscrete")
-})
-
-test_that("scale_color_canva works", {
-  expect_equal(scale_color_colorblind(), scale_colour_colorblind())
+test_that("scale_colour_colourblind works", {
+  expect_s3_class(scale_colour_colourblind(), "ScaleDiscrete")
 })
 
 test_that("scale_fill_colorblind works", {
