@@ -19,7 +19,7 @@ test_that("economist_pal raises warning with large number", {
 })
 
 test_that("scale_colour_economist equals scale_color_economist", {
-  expect_equal(scale_color_economist(), scale_colour_economist())
+  expect_equal_scale(scale_color_economist(), scale_colour_economist())
 })
 
 test_that("scale_colour_economist works", {
@@ -43,9 +43,16 @@ test_that("theme economist with horizontal=FALSE works", {
 test_that("theme economist with dark panel works", {
   thm <- theme_economist(dkpanel = TRUE)
   expect_s3_class(thm, "theme")
-  expect_equal(thm$strip.background$fill,
-               purrr::pluck(dplyr::filter(ggthemes_data$economist$bg,
-                                          name == "dark blue-gray"), "value"))
+  expect_equal(
+    thm$strip.background$fill,
+    purrr::pluck(
+      dplyr::filter(
+        ggthemes_data$economist$bg,
+        name == "dark blue-gray"
+      ),
+      "value"
+    )
+  )
 })
 
 test_that("theme economist_white works", {
@@ -58,7 +65,14 @@ test_that("theme economist_white works", {
 test_that("theme economist_white with gray background works", {
   thm <- theme_economist_white(gray_bg = TRUE)
   expect_s3_class(thm, "theme")
-  expect_equal(thm$plot.background$fill,
-               purrr::pluck(dplyr::filter(ggthemes_data$economist$bg,
-                                          name == "light gray"), "value"))
+  expect_equal(
+    thm$plot.background$fill,
+    purrr::pluck(
+      dplyr::filter(
+        ggthemes_data$economist$bg,
+        name == "light gray"
+      ),
+      "value"
+    )
+  )
 })
