@@ -14,7 +14,7 @@ test_that("scale_colour_stata works", {
 })
 
 test_that("scale_color_stata works", {
-  expect_equal(scale_colour_stata(), scale_color_stata())
+  expect_equal_scale(scale_colour_stata(), scale_color_stata())
 })
 
 test_that("scale_fill_stata works", {
@@ -33,8 +33,7 @@ test_that("theme_stata works", {
 })
 
 test_that("theme_state raises error with invallid scheme", {
-  expect_error(theme_stata(scheme = "dsagasagdadgaga"),
-               regexp = "`scheme` must be one of")
+  expect_error(theme_stata(scheme = "dsagasagdadgaga"), regexp = "`scheme` must be one of")
 })
 
 test_that("stata_shape_pal works", {
